#!/usr/bin/perl
########################################################################
#
#  mkstims.pl
#
#  Make the file defining the MPP2017 stimulus space.
#
#  E. Moreton  *  UNC-Chapel Hill Linguistics  *  2019 July 3 (W)
#
########################################################################

use strict;
use warnings;
use Carp;

# Enables finding other modules in the same directory, even when invoked
# from elsewhere:
# https://perlmaven.com/how-to-add-a-relative-directory-to-inc
use FindBin;
use File::Spec;
use lib File::Spec->catdir($FindBin::Bin, "../..", "New", 'lib');

use Stimulus;
use StimulusSet;
use CELEX;
use GJ2005jrFM;

my $stimset = new StimulusSet;
my $serial;

my @prons;
for my $C1 (qw/ t k d g /) {
    for my $V1 (qw/ i { u Q /) {
	for my $C2 (qw/ t k d g /) {
	    for my $V2 (qw/ i { u Q /) {
		push @prons, "$C1$V1$C2$V2";
	    }
	}
    }
}

for my $pron (@prons) {
    my $pron_rep = &CELEX::to_representation ($pron);
    for my $gender ('F', 'M') {
	my $rep = &GJ2005jrFM::to_representation ($gender);
	$rep->put ($pron_rep);	
	my $stimname = "$gender:$pron";
	$stimset->put (new Stimulus ($rep, ++$serial, $stimname, 0, 1));
    }
}


print (join "\n", $stimset->to_text);
print "\n";

