#!/usr/bin/perl
########################################################################
#
#  getMeanFinalPrCorr.pl
#
#  For each combination of levels of simulation params, get the mean
#  final PrCorr of the macro-constraints across all replications.
#
#  E. Moreton  *  UNC-Chapel Hill Linguistics  *  2019 October 13 ($)
#
########################################################################
use warnings;
use strict;

# Sim directories have names like
# Exp08-2AFC-B-200-random-0.05-0.25-1-1-0.1-0-Mut_0.005-Rec.1.00-0-899
open (LS, "ls . | grep Exp |") or die "Couldn't ls current dir: $!";

my %total;
my %N;
for my $dirname (<LS>) {
    print $dirname;
    chomp $dirname;

    $dirname =~ /(^.*)-(\d\d\d)/ or die "Couldn't parse $dirname: $!";
    my ($codes, $rep) = ($1, $2);
    open (LOG, "grep pr_corr $dirname/Log.txt | tail -1 |") or
	die "Couldn't open $dirname/Log.txt: $!";
    # correct:  F:pu; chosen:  F:tup; pr_corr:  0.5
    my $last_pr_corr = <LOG>;
    $last_pr_corr =~ 'pr_corr:\s*(\d+\.\d+)$' or
	die "Couldn't parse $last_pr_corr: $!";
    $total {$codes} += $1;
    $N{$codes}++;
}

for my $codes (sort keys %total) {
    print "$codes\t";
    printf "%d\t%d\t%6.3f\n", $total{$codes}, $N{$codes}, 
    $total {$codes}/$N{$codes};
}
