#!/usr/bin/perl
########################################################################
#
#  mkstims.pl
#
#  Make the file defining the Reuse9 stimulus space.
#
#  E. Moreton  *  UNC-Chapel Hill Linguistics  *  2019 June 21 (F)
#
########################################################################

use strict;
use warnings;
use Carp;

# Enables finding other modules in the same directory, even when invoked
# from elsewhere:
# https://perlmaven.com/how-to-add-a-relative-directory-to-inc
use FindBin;
use File::Spec;
use lib File::Spec->catdir($FindBin::Bin, "../../..", "Current", 'lib');

use Stimulus;
use StimulusSet;
use GJ2005jrFM;




my $stimset = new StimulusSet;
my $serial;

# Pattern A:  No labial codas, no dorsal codas
# Pattern B:  No labial onsets, no dorsal codas

my %Onset = (
    'A'   => ['', qw/ p t k /],
    'B'   => ['', qw/   t k /],
    'all' => ['', qw/ p t k /]
    );
my %Nucleus = (
    'A'   => ['u'],
    'B'   => ['u'],
    'all' => ['u']
    );
my %Coda = (
    'A'   => ['',      't'   ],
    'B'   => ['', qw/ p t   /],
    'all' => ['', qw/ p t k /]
    );

for my $onset (@{$Onset {'all'}}) {
    for my $nucleus (@{$Nucleus {'all'}}) {
	for my $coda (@{$Coda {'all'}}) {
	    for my $gender ('F', 'M') {

		my $stim = "$gender $onset $nucleus $coda\n";
		$stim =~ s/^\s*//;
		$stim =~ s/\s*$//;
		$stim =~ s/  / /g;
		my $rep = &GJ2005jrFM::to_representation ($stim);

		my $name = "$gender:$onset$nucleus$coda";
		$stimset->put (new Stimulus ($rep, ++$serial, $name, 0, 1));
	    }
	}
    }
}


print (join "\n", $stimset->to_text);
print "\n";

