#!/usr/bin/perl
########################################################################
#
#  mkstims.pl
#
#  Make the file defining the SHJ1961wug stimulus space.
#
#  E. Moreton  *  UNC-Chapel Hill Linguistics  *  2019 Feb. 28 (Th)
#
########################################################################

use strict;
use warnings;
use Carp;

# Enables finding other modules in the same directory, even when invoked
# from elsewhere:
# https://perlmaven.com/how-to-add-a-relative-directory-to-inc
use FindBin;
use File::Spec;
use lib File::Spec->catdir($FindBin::Bin, "../../../", "Current", 'lib');

use Stimulus;
use StimulusSet;
use SHJ1961wug;


my $stimset = new StimulusSet;
my $serial;
for my $iswug ('+', '-') {
    for my $big ('+', '-') {
	for my $black ('+', '-') {
	    for my $triangle ('+', '-') {
		my $name = "$iswug:$big$black$triangle";
		my $rep = &SHJ1961wug::to_representation ($name);
		$stimset->put (new Stimulus ($rep, ++$serial, $name, 0, 1));
		
	    }
	}
    }
}

print (join "\n", $stimset->to_text);
print "\n";

