package EnvironmentVariable;
use warnings;
use strict;
use Carp;

########################################################################
#
# EnvironmentVariable.pm
#
# Object for remembering positive and negative matches of a Variable.
# Used by Environment.
#
########################################################################
#
#   Copyright 2019 by Elliott Moreton.
#
#   This file is part of the Winnow-MaxEnt-Subtree Learner, Version of
#   2019 December 17.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   free software: you can redistribute it and/or modify it under the
#   terms of the GNU General Public License as published by the Free
#   Software Foundation, either version 3 of the License, or (at your
#   option) any later version.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   distributed in the hope that it will be useful, but WITHOUT ANY
#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
#   License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with the Winnow-MaxEnt-Subtree Learner, Version of 2019
#   December 17.  If not, see <https://www.gnu.org/licenses/>.
#
########################################################################


sub new {
    my (
	$class,
	$variable
	) = @_;

    unless (ref ($variable) and $variable->isa ('Variable')) {
	carp "Found ", ref (\$variable), " while looking for a Variable: $!";
	confess;
	die;
    }

    my $this = {};

    $this->{variable} = $variable;

    # Arrays for storing things matched by "+variable" and "-variable":
    @{$this->{positive}} = ();
    @{$this->{negative}} = ();

    bless $this, $class;
    $this;
}

sub clone {
    my $this = shift;
    my $copy = new EnvironmentVariable ($this->get_variable);
    for ($this->get_all_positive_cases) {
	$copy->add_positive_case ($_);
    }
    for ($this->get_all_negative_cases) {
	$copy->add_negative_case ($_);
    }
    $copy;
}

########################################################################
#
# Access methods
#
########################################################################

sub get_variable {
    my $this = shift;
    $this->{variable};
}

sub get_name {
    my $this = shift;
    $this->get_variable->get_name;
}

sub get_all_positive_cases {
    my $this = shift;
    @{$this->{positive}};
}

sub get_all_negative_cases {
    my $this = shift;
    @{$this->{negative}};
}

sub add_case {
    my (
	$this,
	$case,
	$which
	) = @_;

    unless (ref $case) {
	carp "Can't add ", \$case, " as case of EnvironmentVariable $this: $!";
	confess; 
	die;
    }
    unless ($case->get_genus_name eq $this->get_variable->get_genus_name) {
	carp "Can't add node of genus ", $case->get_genus_name, " as case of EnvironmentVariable $this: $!";
	confess;
	die;
    }

    push @{$this->{$which}}, $case;
    $case;
}

sub add_positive_case {
    my (
	$this,
	$case
	) = @_;
    $this->add_case ($case, 'positive');
}

sub add_negative_case {
    my (
	$this,
	$case
	) = @_;
    $this->add_case ($case, 'negative');
}

########################################################################
#
# I/O methods
#
########################################################################

sub print {
    my $this = shift;
    $this->get_variable->print;
    print "positive cases:\n";
    for ($this->get_all_positive_cases) {
	$_->print;
    }
    print "negative cases:\n";
    for ($this->get_all_negative_cases) {
	$_->print;
    }
}

1;

    
