package Globals;
use Representations;
use ConstraintSet;
use warnings;
use strict; 
use Carp;

# For finding out where this very script lives
#use FindBin;
use File::Basename;

########################################################################
#
# Globals.pm
#
# Where we keep the global variables and the routines for common use.
#
########################################################################
#
#   Copyright 2019 by Elliott Moreton.
#
#   This file is part of the Winnow-MaxEnt-Subtree Learner, Version of
#   2019 December 17.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   free software: you can redistribute it and/or modify it under the
#   terms of the GNU General Public License as published by the Free
#   Software Foundation, either version 3 of the License, or (at your
#   option) any later version.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   distributed in the hope that it will be useful, but WITHOUT ANY
#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
#   License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with the Winnow-MaxEnt-Subtree Learner, Version of 2019
#   December 17.  If not, see <https://www.gnu.org/licenses/>.
#
########################################################################


# Set to 1 to enable painfully exact checking
our $DEBUG = 0;

# The representational system that everyone uses:
our $rep;
sub set_representations {
    $rep = shift;
}
sub get_representations {
    $rep;
}

# Directory where the modules live:
# https://stackoverflow.com/questions/35104362/perl-relative-path-of-a-file-inside-a-module
our $home_dir = File::Basename::dirname( eval { ( caller() )[1] } );


########################################################################
#
# I/O formatting
#
########################################################################

# Indent each level by another copy of this string.
our $indent = '  ';
our $indent_re = '\ \ ';  # For regexp matching $indent


# Given a path to a file, read it in, clean it up, and return a pointer
# to an array with one line per element.
sub read_text {
    my $pathname  = shift;

    unless (open (TEXT, "< $pathname")) {
	carp "Can't read from $pathname: $!";
	confess;
	die;
    }

    my @text;
    while ($_ = <TEXT>) {

	# Ignore comments
	next if (/^\s*[;#]/);

	# Replace tabs with eight spaces
	s/\t/        /g;

	push (@text, $_);
    }

    close TEXT;

    @text;
}


1;

