package UnaryFeatureGenus;
use UnaryFeatureVariable;
use FeatureGenus;
use strict;
use warnings;
use Carp;

our @ISA = qw ( FeatureGenus );

########################################################################
#
# UnaryFeatureGenus.pm
#
# A subclass of FeatureGenus with arity 1 and range {+}.
#
# E. Moreton  *  UNC-Chapel Hill Linguistics  *  2009 March 8 ($)
#
########################################################################
#
#   Copyright 2019 by Elliott Moreton.
#
#   This file is part of the Winnow-MaxEnt-Subtree Learner, Version of
#   2019 December 17.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   free software: you can redistribute it and/or modify it under the
#   terms of the GNU General Public License as published by the Free
#   Software Foundation, either version 3 of the License, or (at your
#   option) any later version.
#
#   The Winnow-MaxEnt-Subtree Learner, Version of 2019 December 17, is
#   distributed in the hope that it will be useful, but WITHOUT ANY
#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
#   License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with the Winnow-MaxEnt-Subtree Learner, Version of 2019
#   December 17.  If not, see <https://www.gnu.org/licenses/>.
#
########################################################################


########################################################################
#
# Constructors
#
########################################################################

sub new {
    my $class = shift;
    my ($name, $abbrev) = @_;
    $abbrev = $name unless ($abbrev);

    my $this = new FeatureGenus ($name, $abbrev, +1);

    bless ($this, $class);

    $this;
}

########################################################################
#
# Methods for creating Features of this UnaryFeatureGenus
#
########################################################################

# plus, minus -- plus () creates a new instance of [+Foo]; minus () 
#     gives an error message (since this is a unary feature); 
#     plus ("alpha") and minus ("alpha") give [+/-alpha Foo].

sub plus {
    my $this = shift;
    my $species = shift;
    if ($species) {
	plus UnaryFeatureVariable ($this, $species);
    } else {
	plus UnaryFeature ($this);
    }
}

sub minus {
    my $this = shift;
    my $species = shift;
    if ($species) {
	minus UnaryFeatureVariable ($this, $species);
    } else {
	carp "UnaryFeature must be +, not -";
	confess;
	die;
    }
}

1;
