use FindBin;
use lib "$FindBin::Bin/../lib/";
use Learner;
use Mutagen;
use Constraint;
use GJ2005jr;

########################################################################
#
# test.Learner.pl
#
# Create a Learner object and train it on two dead-simple patterns 
# (simplified Saffran & Thiessen 2003) just to see if the code works.
#
# E. Moreton  *  UNC-Chapel Hill Linguistics  *  2009 March 8 ($)
#
########################################################################

$outfile = (shift (@ARGV) or '-');
open (OUT, "> $outfile") or
    die "Couldn't open $outfile: $!";

# Learner 1:  trained on btg vs. pdk.
my $L1 = new Learner;

@pos1 = (
    "b ' a", "t ' a", "g ' a", 
    "b ' i", "t ' i", "g ' i", 
    "b ' u", "t ' u", "g ' u");
@neg1 =  (
#    @pos1, 
    "p ' a", "d ' a", "k ' a", 
    "p ' i", "d ' i", "k ' i", 
    "p ' u", "d ' u", "k ' u");

# Learner 2:  trained on bdg vs. ptk.
my $L2 = new Learner;

@pos2 = (
    "b ' a", "d ' a", "g ' a", 
    "b ' i", "d ' i", "g ' i", 
    "b ' u", "d ' u", "g ' u");
@neg2 =  (
#    @pos1, 
    "p ' a", "t ' a", "k ' a", 
    "p ' i", "t ' i", "k ' i", 
    "p ' u", "t ' u", "k ' u");



$C_minus =  &Constraint::from_text (
    "-Constraint",
    "  (- Prosodic Word -)"
    );

$No_b = &Constraint::from_text (
    "-Constraint",
    "  (L Prosodic Word -)",
    "    (L Syllable -)",
    "      [+Root]",
    "        [+Place]",
    "          [+Lab]",
    "        [+Laryngeal]",
    "          [+voiced]"
    );

$No_t = &Constraint::from_text (
    "-Constraint",
    "  (L Prosodic Word -)",
    "    (L Syllable -)",
    "      [+Root]",
    "        [+Place]",
    "          [+Cor]",
    "        [+Laryngeal]",
    "          [-voiced]"
    );

$No_d = &Constraint::from_text (
    "-Constraint",
    "  (L Prosodic Word -)",
    "    (L Syllable -)",
    "      [+Root]",
    "        [+Place]",
    "          [+Cor]",
    "        [+Laryngeal]",
    "          [+voiced]"
    );

$No_g = &Constraint::from_text (
    "-Constraint",
    "  (L Prosodic Word -)",
    "    (L Syllable -)",
    "      [+Root]",
    "        [+Place]",
    "          [+Dor]",
    "        [+Laryngeal]",
    "          [+voiced]"
    );

$No_Voiceless = &Constraint::from_text (
    "-Constraint",
    "  (L Prosodic Word -)",
    "    (L Syllable -)",
    "      [+Root]",
    "        [+Laryngeal]",
    "          [+voiced]"
    );

$scale = 1;
$MG_const = new Mutagen (
    P_mutate                        => 1, 
    P_invert_polarity               => 0    * $scale,
    P_add_constituent               => 0.05 * $scale,
    P_delete_constituent            => 0.05 * $scale,
    P_duplicate_constituent         => 0    * $scale,
    P_gain_head                     => 0    * $scale,
    P_lose_head                     => 0    * $scale,
    P_head_no_head                  => 0    * $scale,
    P_move_head                     => 0    * $scale,
    P_flip_anchor                   => 0.05 * $scale,

    P_gain_unary                    => 0.05 * $scale,
    P_lose_unary                    => 0.05 * $scale,
    P_gain_binary                   => 0.05 * $scale,
    P_lose_binary                   => 0.05 * $scale,

    P_invert_unary_coefficient      => 0.05 * $scale,
    P_invert_binary_coefficient     => 0.05 * $scale,
    P_invert_PrCat_coefficient      => 0.05 * $scale,

    P_unary_feature_to_variable     => 0.0 * $scale,
    P_unary_variable_to_feature     => 0.0 * $scale,
    P_binary_feature_to_variable    => 0.0 * $scale,
    P_binary_variable_to_feature    => 0.0 * $scale,
    P_PrCat_to_PrCat_variable       => 0.0 * $scale,
    P_PrCat_variable_to_PrCat       => 0.0 * $scale,
    );
$MG_const->protect_PrCat_parents;
$MG_const->protect_feature_parents;



$times = 1;
for (@pos1) {
    $stim = new Stimulus (&GJ2005jr::to_representation ($_), 1, 1);
    $L1->add_training_stimulus ($stim);
}

for (@neg1) {
    $stim = new Stimulus (&GJ2005jr::to_representation ($_), -1, 1);
    $L1->add_training_stimulus ($stim);
}

if (1) {
    for (1..5) {
	$L1->add_constraint ($No_b->clone);
    }
    for (1..5) {
	$L1->add_constraint ($No_d->clone);
    }
    for (1..5) {
	$L1->add_constraint ($No_t->clone);
    }
    for (1..5) {
	$L1->add_constraint ($No_g->clone);
	}
    for (1..5) {
	$L1->add_constraint ($No_Voiceless->clone);
    }
}


$L1->set_constraint_mutagen ($MG_const);
$L1->set_eta (0.25);
$L1->set_zeta (0.1);
$L1->print;

select (OUT);
my @twoAFC;
my @prcorr;

my $inc = 1;
my $max_trial = 10;

if (1) {
    $L1->initialize;

    print "\n=========== START ===========\n";
    for $i (1..$max_trial) {
	push @twoAFC, ($L1->learn)[2];
	$L1->report;
	print "\n=========== $i ===========\n";
	my $total; 
	for (@twoAFC [($i-$inc)..($i-1)]) {$total += $_};
	printf "L1 PrCorr = %5.3f", $total/$inc;
	push @prcorr, $total/$inc;
	print "\n";
	print "=========== $i ===========\n";
    }
}

print OUT (join "\n", $L1->to_text);

close (OUT);
