use UnaryFeatureGenus;
use BinaryFeatureGenus;
use PrCatGenus;

use IPA;

# Check that all of the alpha variables are being interpreted correctly,
# by matching all possible [+/- alpha Foo][+/- alpha Foo] in all possible
# [+/- Foo][+/- Foo].


print "="x72, "\n";
print "BINARY FEATURES\n";
print "="x72, "\n";

for $alpha_coeff_1  ('plus', 'minus') {
    for $alpha_coeff_2 ('plus', 'minus') {
	$con = $IPA::SYLL->unanchored;
	$con->put ($IPA::Root->plus, $IPA::nas->$alpha_coeff_1 ("alpha"));
	$con->put ($IPA::Root->plus, $IPA::nas->$alpha_coeff_2 ("alpha"));
	
	print "\n";
	print "Constraint:  "; $con->print;
	print "\n";

	for $coeff_1 ('plus', 'minus') {
	    for $coeff_2 ('plus', 'minus') {
		print "Matching constraint in representation:\n";
		$rep = $IPA::SYLL->double_anchored;
		$rep->put ($IPA::Root->plus,
			   $IPA::nas->$coeff_1
		    );
		$rep->put ($IPA::Root->plus,
			   $IPA::nas->$coeff_2
		    );
		print "Representation: "; $rep->print;
		print "Matches:  ", 0+$con->matches_in ($rep), "\n\n";

		print "Matching constraint in other constraint:\n";
		$con2 = $IPA::SYLL->unanchored;
		$con2->put ($IPA::Root->plus, $IPA::nas->$coeff_1 ("alpha"));
		$con2->put ($IPA::Root->plus, $IPA::nas->$coeff_2 ("alpha"));
		print "Other constraint: "; $con2->print;
		print "Matches:  ", 0+$con->matches_in ($con2), "\n\n";
	    }
	}
    }

}

print "="x72, "\n";
print "UNARY FEATURES WITH DEPENDENTS\n";
print "="x72, "\n";

for $alpha_coeff_1  ('plus', 'minus') {
    for $alpha_coeff_2 ('plus', 'minus') {
	$con = $IPA::SYLL->unanchored;
	$con->put ($IPA::Root->plus, $IPA::Lar->$alpha_coeff_1 ("alpha"));
	$con->put ($IPA::Root->plus, $IPA::Lar->$alpha_coeff_2 ("alpha"));
	
	print "\n";
	print "Constraint:  "; $con->print;
	print "\n";

	for $coeff_1 ('plus', 'minus') {
	    for $coeff_2 ('plus', 'minus') {
		$rep = $IPA::SYLL->double_anchored;
		$rep->put ($IPA::Root->plus,
			   $IPA::Lar->plus,
			   $IPA::voi->$coeff_1
		    );
		$rep->put ($IPA::Root->plus,
			   $IPA::Lar->plus,
			   $IPA::voi->$coeff_2
		    );

		print "Representation: "; $rep->print;
		print "Matches:  ", 0+$con->matches_in ($rep), "\n\n";
	    }
	}		
    }
}

print "="x72, "\n";
print "PROSODIC CATEGORIES\n";
print "="x72, "\n";

for $alpha_coeff_1  ('plus', 'minus') {
    for $alpha_coeff_2 ('plus', 'minus') {
	$con = $IPA::PRWD->unanchored;
	$con->put ($IPA::SYLL->$alpha_coeff_1 ("alpha"));
	$con->put ($IPA::SYLL->$alpha_coeff_2 ("alpha"));
	
	print "\n";
	print "Constraint:  "; $con->print;
	print "\n";

	for $syll_1 ('b * a', 'g * i') {
	    for $syll_2 ('b * a', 'g * i') {
		$rep = &IPA::to_representation (
		    "$syll_1 . $syll_2"
		    );
		print "Representation: "; $rep->print;
		print "Matches:  ", 0+$con->matches_in ($rep), "\n\n";
	    }
	}		
    }
}

